@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration into rhythmic phrases
 
-our $VERSION = '0.0801';
+our $VERSION = '0.0802';
 
 use Moo;
 use strictures 2;
@@ -193,6 +193,14 @@ sub motifs {
     return @motifs;
 }
 
+
+sub add_to_score {
+    my ($self, $score, $motif, $notes) = @_;
+    for my $i (0 .. $#$motif) {
+        $score->n($motif->[$i], $notes->[$i]);
+    }
+}
+
 sub _duration {
     my ( $self, $name ) = @_;
 
@@ -222,7 +230,7 @@ Music::Duration::Partition - Partition a musical duration into rhythmic phrases
 
 =head1 VERSION
 
-version 0.0801
+version 0.0802
 
 =head1 SYNOPSIS
 
@@ -238,25 +246,25 @@ version 0.0801
   $mdp = Music::Duration::Partition->new(
     size    => 100,
     pool    => [qw(d50  d25)],
-    weights => [   0.7, 0.3], # optional
+    weights => [   0.7, 0.3 ], # optional
   );
 
   # the pool may also be grouped
   $mdp = Music::Duration::Partition->new(
     pool   => [qw(hn qn tqn)],
-    groups => [   1, 1, 3], # optional
+    groups => [   1, 1, 3   ], # optional
   );
 
-  my $motif = $mdp->motif; # Random list-ref of pool members
+  my $motif  = $mdp->motif;  # list-ref of pool members
+  my @motifs = $mdp->motifs; # list-ref of individual motifs
 
   # midi usage:
-  # use MIDI::Util (setup_score);
-  # use Music::Scales;
-  # my @scale = get_scale_MIDI('C', 4, 'major');
-  # my $score = setup_score();
-  # for my $n (0 .. 31) { # 32/8=4 loops over the motif
-  #   $score->n($motif->[$n % @$motif], $scale[int rand @scale]);
-  # }
+  # use List::Util qw(shuffle);
+  # use MIDI::Simple ();
+  # use Music::Scales qw(get_scale_MIDI);
+  # my $score = MIDI::Simple->new;
+  # my @notes = shuffle get_scale_MIDI('C', 4, 'major');
+  # $mdp->add_to_score($score, $motif, \@notes);
   # $score->write_score('motif.mid');
 
 =head1 DESCRIPTION
@@ -380,6 +388,12 @@ application, in a loop until the B<size> is met.
 
 Return B<n> motifs.
 
+=head2 add_to_score
+
+  $mdp->add_to_score($score, $motif, $notes);
+
+Return B<n> motifs.
+
 =head1 SEE ALSO
 
 The F<eg/*> and F<t/01-methods.t> programs in this distribution.
